@@ -6,7 +6,7 @@ from .models import Hero, Team
 
 def create_heroes():
     with Session(engine) as session:
-        team_z_force = Team(name="Z-Force", headquarters="Sister Margaret’s Bar")
+        team_z_force = Team(name="Z-Force", headquarters="Sister Margaret's Bar")
 
         hero_deadpond = Hero(
             name="Deadpond", secret_name="Dive Wilson", team=team_z_force
