@@ -30,7 +30,7 @@ expected_calls = [
 ]
 
 
-def test_tutorial(clear_sqlmodel):
+def test_tutorial():
     from docs_src.advanced.decimal import tutorial001 as mod
 
     mod.sqlite_url = "sqlite://"
