@@ -6,7 +6,7 @@ from ....conftest import needs_py310
 
 
 @needs_py310
-def test_tutorial001(clear_sqlmodel):
+def test_tutorial001():
     from docs_src.tutorial.connect.create_tables import tutorial001_py310 as mod
 
     mod.sqlite_url = "sqlite://"
