@@ -39,7 +39,7 @@ expected_calls = [
 
 
 @needs_py310
-def test_tutorial001(clear_sqlmodel):
+def test_tutorial001():
     from docs_src.tutorial.connect.insert import tutorial001_py310 as mod
 
     mod.sqlite_url = "sqlite://"
