@@ -48,7 +48,7 @@ expected_calls = [
 ]
 
 
-def test_tutorial(clear_sqlmodel):
+def test_tutorial():
     from docs_src.tutorial.connect.select import tutorial004 as mod
 
     mod.sqlite_url = "sqlite://"
