@@ -51,7 +51,7 @@ expected_calls = [
 
 
 @needs_py310
-def test_tutorial(clear_sqlmodel):
+def test_tutorial():
     from docs_src.tutorial.connect.select import tutorial005_py310 as mod
 
     mod.sqlite_url = "sqlite://"
