@@ -4,16 +4,6 @@ from sqlmodel import create_engine
 
 from ...conftest import get_testing_print_function
 
-expected_calls = [
-    [
-        [
-            {"id": 5, "name": "Black Lion", "secret_name": "Trevor Challa", "age": 35},
-            {"id": 6, "name": "Dr. Weird", "secret_name": "Steve Weird", "age": 36},
-            {"id": 3, "name": "Rusty-Man", "secret_name": "Tommy Sharp", "age": 48},
-        ]
-    ]
-]
-
 
 def test_tutorial(clear_sqlmodel):
     from docs_src.tutorial.offset_and_limit import tutorial004 as mod
@@ -26,4 +16,11 @@ def test_tutorial(clear_sqlmodel):
 
     with patch("builtins.print", new=new_print):
         mod.main()
-    assert calls == expected_calls
+    assert calls == [
+        [
+            [
+                {"name": "Dr. Weird", "secret_name": "Steve Weird", "age": 36, "id": 6},
+                {"name": "Rusty-Man", "secret_name": "Tommy Sharp", "age": 48, "id": 3},
+            ]
+        ]
+    ]
